### Info
The pip package is called `terminally` but the command is `ally`.

### Config
On the first run, if you're running Linux a configuration file and dataset is created on:
```sh
~/.config/terminally/config.json
~/.config/terminally/dataset.jsonl
```
All you need is to bring your own `OPENAI_API_KEY`!

### DataSet
In the current beta-testing version, the dataset is a collection of your prompts and gpt's completions. 
The goal is to train a better model in the future, so if you're up for contributing share your `dataset.jsonl` with us. 
You can find us on Discord: https://discord.gg/DgNKk4WJ